import sys
import pandas as pd
from xml.etree import ElementTree

from pyrsistent import get_in


def merge(files):
    xml_data = None
    for filename in files:
        data = ElementTree.parse(filename).getroot()
        if xml_data is None:
            xml_data = data
        else:
            xml_data.extend(data)
    if xml_data is not None:
        return ElementTree.tostring(xml_data).decode('utf-8')


def csv(xml_data, new_file):
    root = ElementTree.XML(xml_data)
    data, cols = [], []
    for child in root:
        data.append([subchild.text for subchild in child])
        cols.append(child.tag)

    df = pd.DataFrame(data).T
    df.columns = cols
    df.to_csv(new_file, index=False)


def help():
    print("Usage xmlmerge  <xml-files> > <new-file>")
    print("Usage xmlmerge  -csv <csv-file> <xml-files>")
    print("                -h | --help")

def version():
    print("xmlmerge version: 1.0.1")

def get_index(given_list, element):
    try:
        return given_list.index(element)
    except ValueError:
        return None


def run():
    if len(sys.argv) <= 2:
        help()

    _help = ['-h', '--help']
    _csv = ['-csv']
    _version = ['-v', '--version']
    
    for each in _help:
        if get_index(sys.argv, each):
            help()
            return

    for each in _version:
        if get_index(sys.argv, each):
            version()
            return

    files = []
    csv_name = None
    for i in sys.argv[1:]:
        files.append(i) if '.xml' in i else None
        csv_name = i if '.csv' in i else None

    for each in _csv:
        if get_index(sys.argv, each):
            if csv_name is None:
                csv_name = "xml_to_csv.csv"
            csv(merge(files), csv_name)
            return

    if len(files) == 0:
        print("no xml files found")
        print("you can test with either ls/dir <your-input>")
        return

    print("xml files planning to merge are: ")
    print(files)
    print(merge(files))


if __name__ == '__main__':
    run()



from setuptools import setup, find_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))
reqs = []

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

with open(path.join(here, '.version'), encoding='utf-8') as f:
    version = f.read()

with open(path.join(here, 'requirements.txt'), encoding='utf-8') as f:
    read_lines = f.readlines()
    reqs = [each.strip() for each in read_lines]

setup(
    name = 'xmlmerge',
    version = version,
    description = "XMLMerge is simple tool to merge multiple xml files.",
    long_description = long_description,
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/kirankotari/xmlmerge.git',
    author = 'Kiran Kumar Kotari',
    author_email = 'kirankotari@live.com',
    entry_points={
        'console_scripts': [
            'xmlmerge=xmlmerge.xmlmerge:run'
        ],
    },
    install_requires=reqs,
    classifiers = [
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        ],
    keywords = 'xml xmlmerge',
    packages = find_packages(where='.', exclude=['tests']),
    include_package_data=True,
)

